eprllib.RewardFunctions.energy_and_cen15251 — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions.energy_and_cen15251

## Energy and CEN 15251 reward function

The standard CEN 15251 stablish three categories of acceptability of the thermal condition as is show in table below.

See Engineering Reference of EnergyPlus documentation 19.1.6 Adaptive Comfort Model Based on European Standard EN15251-2007 for more information.

Classes

`reward_fn`(reward_fn_config) |